[![pipeline  status](https://gitlab.com/octomy/batch/badges/production/pipeline.svg)](https://gitlab.com/octomy/batch/-/commits/production)

<!---
                                                         
                                                         
     ## ## ## ## ## ## ## ## ## ## ##                    
        ## ## ## ## ## ## ## ## ##                       
           ## ## ## ## ## ## ##                          
              ## ## ## ## ##                             
                 ## ## ##                                
                    ##                                   
                                                         
                                                         
WARNING: This file is AUTO GENERATED from "resources/templates/README.md".
         Any changes you make will be OVERWRITTEN at the 
         next invocation of `make readme`                
                                                         
                                                         
                    ##                                   
                 ## ## ##                                
              ## ## ## ## ##                             
           ## ## ## ## ## ## ##                          
        ## ## ## ## ## ## ## ## ##                       
     ## ## ## ## ## ## ## ## ## ## ##                    
                                                         
                                                         
-->

#  Practical details
<img  src="https://gitlab.com/octomy/batch/-/raw/production/resources/iamges/logos/1024.svg"  width="20%"/>

This is the batch project version 1.0.74

- The website should be [live here](https://oktopus.octomy).
- batch is [available  on  gitlab](https://gitlab.com/octomy/batch).
- batch is [available as private Docker image](https://gitlab.com/octomy/batch/container_registry).


```shell
#  Clone  git  repository
git  clone  git@gitlab.com:octomy/batch.git
```

```shell
# Pull image from Docker registry
docker pull registry.gitlab.com/octomy/batch

```


# What is batch?

batch is an scalable asynchronous task execution system similar to cellery but tailored to the needs of OctoMY.


FK_CLI_OUTPUT=""
FK_CLI_EXECUTABLE="true"
FK_HAS_CLI_EXECUTABLE="false"


